@@ -69,16 +69,13 @@ class TestFFWDUpgradePrepare(fakes.TestFFWDUpgradePrepare):
         mock_stack = mock.Mock()
         mock_stack.stack_name = 'mystack'
         mock_get_stack.return_value = mock_stack
-        mock_abspath.return_value = '/home/fake/my-fake-registry.yaml'
         mock_yaml.return_value = {'fake_container': 'fake_value'}
 
         argslist = ['--stack', 'mystack', '--templates',
-                    '--container-registry-file', 'my-fake-registry.yaml',
                     '--yes']
         verifylist = [
             ('stack', 'mystack'),
             ('templates', constants.TRIPLEO_HEAT_TEMPLATES),
-            ('container_registry_file', 'my-fake-registry.yaml'),
             ('yes', True),
         ]
 
@@ -87,7 +84,6 @@ class TestFFWDUpgradePrepare(fakes.TestFFWDUpgradePrepare):
         mock_ffwd_upgrade.assert_called_once_with(
             self.app.client_manager,
             container='mystack',
-            container_registry={'fake_container': 'fake_value'},
             ceph_ansible_playbook='/usr/share/ceph-ansible'
                                   '/site-docker.yml.sample',
         )
@@ -110,15 +106,12 @@ class TestFFWDUpgradePrepare(fakes.TestFFWDUpgradePrepare):
         self, mock_deploy, mock_copy, mock_yaml, mock_abspath, mock_open,
             mock_ffwd_upgrade, mock_prepend_env):
         mock_ffwd_upgrade.side_effect = exceptions.DeploymentError()
-        mock_abspath.return_value = '/home/fake/my-fake-registry.yaml'
         mock_yaml.return_value = {'fake_container': 'fake_value'}
         argslist = ['--stack', 'overcloud', '--templates',
-                    '--container-registry-file', 'my-fake-registry.yaml',
                     '--yes', ]
         verifylist = [
             ('stack', 'overcloud'),
             ('templates', constants.TRIPLEO_HEAT_TEMPLATES),
-            ('container_registry_file', 'my-fake-registry.yaml'),
             ('yes', True),
         ]
         parsed_args = self.check_parser(self.cmd, argslist, verifylist)
@@ -149,8 +142,8 @@ class TestFFWDUpgradeRun(fakes.TestFFWDUpgradeRun):
     def test_ffwd_upgrade_playbook(
             self, mock_open, mock_execute, mock_expanduser, upgrade_ansible):
         mock_expanduser.return_value = '/home/fake/'
-        argslist = ['--yes']
-        verifylist = [('yes', True), ]
+        argslist = ['--ssh-user', 'heat-admin', '--yes']
+        verifylist = [('ssh_user', 'heat-admin'), ('yes', True), ]
 
         parsed_args = self.check_parser(self.cmd, argslist, verifylist)
         with mock.patch('os.path.exists') as mock_exists:
@@ -166,6 +159,31 @@ class TestFFWDUpgradeRun(fakes.TestFFWDUpgradeRun):
                 skip_tags=''
             )
 
+    @mock.patch('tripleoclient.workflows.package_update.update_ansible',
+                autospec=True)
+    @mock.patch('os.path.expanduser')
+    @mock.patch('oslo_concurrency.processutils.execute')
+    @mock.patch('six.moves.builtins.open')
+    def test_ffwd_upgrade_playbook_non_default_user(
+            self, mock_open, mock_execute, mock_expanduser, upgrade_ansible):
+        mock_expanduser.return_value = '/home/fake/'
+        argslist = ['--ssh-user', 'my-user', '--yes']
+        verifylist = [('ssh_user', 'my-user'), ('yes', True), ]
+
+        parsed_args = self.check_parser(self.cmd, argslist, verifylist)
+        with mock.patch('os.path.exists') as mock_exists:
+            mock_exists.return_value = True
+            self.cmd.take_action(parsed_args)
+            upgrade_ansible.assert_called_once_with(
+                self.app.client_manager,
+                inventory_file=mock_open().read(),
+                ansible_queue_name=constants.FFWD_UPGRADE_QUEUE,
+                nodes='',
+                playbook=constants.FFWD_UPGRADE_PLAYBOOK,
+                node_user='my-user',
+                skip_tags=''
+            )
+
     @mock.patch('tripleoclient.workflows.package_update.update_ansible',
                 autospec=True)
     @mock.patch('os.path.expanduser')
@@ -190,33 +208,10 @@ class TestFFWDUpgradeConverge(fakes.TestFFWDUpgradeConverge):
         app_args.verbose_level = 1
         self.cmd = overcloud_ffwd_upgrade.FFWDUpgradeConverge(self.app,
                                                               app_args)
-        uuid4_patcher = mock.patch('uuid.uuid4', return_value="UUID4")
-        self.mock_uuid4 = uuid4_patcher.start()
-        self.addCleanup(self.mock_uuid4.stop)
 
-    @mock.patch('tripleoclient.utils.prepend_environment', autospec=True)
-    @mock.patch('tripleoclient.utils.get_stack', autospec=True)
-    @mock.patch('tripleoclient.workflows.package_update.ffwd_converge_nodes',
-                autospec=True)
-    @mock.patch('os.path.expanduser')
-    @mock.patch('oslo_concurrency.processutils.execute')
-    @mock.patch('six.moves.builtins.open')
-    @mock.patch('tripleoclient.v1.overcloud_deploy.DeployOvercloud.'
-                '_deploy_tripleo_heat_templates_tmpdir', autospec=True)
-    def test_ffwd_upgrade_converge(
-        self,
-            mock_deploy,
-            mock_open,
-            mock_execute,
-            mock_expanduser,
-            ffwd_converge_nodes,
-            mock_get_stack,
-            mock_prepend_env):
-
-        mock_expanduser.return_value = '/home/fake/'
-        mock_stack = mock.Mock()
-        mock_stack.stack_name = 'le_overcloud'
-        mock_get_stack.return_value = mock_stack
+    @mock.patch(
+        'tripleoclient.v1.overcloud_deploy.DeployOvercloud.take_action')
+    def test_ffwd_upgrade_converge(self, deploy_action):
         argslist = ['--stack', 'le_overcloud', '--templates', '--yes']
         verifylist = [
             ('stack', 'le_overcloud'),
@@ -224,10 +219,13 @@ class TestFFWDUpgradeConverge(fakes.TestFFWDUpgradeConverge):
             ('yes', True)
         ]
         parsed_args = self.check_parser(self.cmd, argslist, verifylist)
-        with mock.patch('os.path.exists') as mock_exists:
+
+        with mock.patch('os.path.exists') as mock_exists, \
+                mock.patch('os.path.isfile') as mock_isfile:
             mock_exists.return_value = True
+            mock_isfile.return_value = True
             self.cmd.take_action(parsed_args)
-            ffwd_converge_nodes.assert_called_once_with(
-                self.app.client_manager,
-                queue_name=constants.FFWD_UPGRADE_QUEUE,
-                container='le_overcloud')
+            assert('/usr/share/openstack-tripleo-heat-templates/'
+                   'environments/lifecycle/ffwd-upgrade-converge.yaml'
+                   in parsed_args.environment_files)
+            deploy_action.assert_called_once_with(parsed_args)
